============
Installation
============

At the command line::

    % pip install sahuwai

Development version::

    % git clone git://gitorious.org/sahuwai/rrda.git
    % cd rrda
    % python setup.py install

